==> pystan-2.1.0.0.tar.gz: pystan-2.1.0.0/pystan/stan/src/stan/agrad/rev/matrix.hpp <==
#ifndef __STAN__AGRAD__REV__MATRIX_HPP__
#define __STAN__AGRAD__REV__MATRIX_HPP__

#include <stan/agrad/rev/matrix/Eigen_NumTraits.hpp>
#include <stan/agrad/rev/matrix/crossprod.hpp>
#include <stan/agrad/rev/matrix/determinant.hpp>
#include <stan/agrad/rev/matrix/divide.hpp>
#include <stan/agrad/rev/matrix/dot_product.hpp>
#include <stan/agrad/rev/matrix/dot_self.hpp>
#include <stan/agrad/rev/matrix/grad.hpp>
#include <stan/agrad/rev/matrix/initialize_variable.hpp>
#include <stan/agrad/rev/matrix/ldlt.hpp>
#include <stan/agrad/rev/matrix/log_determinant.hpp>
#include <stan/agrad/rev/matrix/log_determinant_spd.hpp>
#include <stan/agrad/rev/matrix/log_softmax.hpp>
#include <stan/agrad/rev/matrix/log_sum_exp.hpp>
#include <stan/agrad/rev/matrix/mdivide_left.hpp>
#include <stan/agrad/rev/matrix/mdivide_left_spd.hpp>
#include <stan/agrad/rev/matrix/mdivide_left_tri.hpp>
#include <stan/agrad/rev/matrix/multiply.hpp>
#include <stan/agrad/rev/matrix/multiply_lower_tri_self_transpose.hpp>
#include <stan/agrad/rev/matrix/quad_form.hpp>
#include <stan/agrad/rev/matrix/sd.hpp>
#include <stan/agrad/rev/matrix/softmax.hpp>
#include <stan/agrad/rev/matrix/sort.hpp>
#include <stan/agrad/rev/matrix/squared_dist.hpp>
#include <stan/agrad/rev/matrix/stan_print.hpp>
#include <stan/agrad/rev/matrix/stored_gradient_vari.hpp>
#include <stan/agrad/rev/matrix/sum.hpp>
#include <stan/agrad/rev/matrix/tcrossprod.hpp>
#include <stan/agrad/rev/matrix/to_var.hpp>
#include <stan/agrad/rev/matrix/trace_gen_quad_form.hpp>
#include <stan/agrad/rev/matrix/trace_quad_form.hpp>
#include <stan/agrad/rev/matrix/typedefs.hpp>
#include <stan/agrad/rev/matrix/value_of.hpp>
#include <stan/agrad/rev/matrix/variance.hpp>

#include <stan/agrad/rev/error_handling/matrix.hpp>

#endif

==> pystan-2.3.0.0.tar.gz: pystan-2.3.0.0/pystan/stan/src/stan/agrad/rev/matrix.hpp <==
#ifndef __STAN__AGRAD__REV__MATRIX_HPP__
#define __STAN__AGRAD__REV__MATRIX_HPP__

#include <stan/agrad/rev/matrix/Eigen_NumTraits.hpp>
#include <stan/agrad/rev/matrix/LDLT_alloc.hpp>
#include <stan/agrad/rev/matrix/LDLT_factor.hpp>
#include <stan/agrad/rev/matrix/crossprod.hpp>
#include <stan/agrad/rev/matrix/determinant.hpp>
#include <stan/agrad/rev/matrix/divide.hpp>
#include <stan/agrad/rev/matrix/dot_product.hpp>
#include <stan/agrad/rev/matrix/dot_self.hpp>
#include <stan/agrad/rev/matrix/grad.hpp>
#include <stan/agrad/rev/matrix/initialize_variable.hpp>
#include <stan/agrad/rev/matrix/log_determinant.hpp>
#include <stan/agrad/rev/matrix/log_determinant_ldlt.hpp>
#include <stan/agrad/rev/matrix/log_determinant_spd.hpp>
#include <stan/agrad/rev/matrix/log_softmax.hpp>
#include <stan/agrad/rev/matrix/log_sum_exp.hpp>
#include <stan/agrad/rev/matrix/mdivide_left.hpp>
#include <stan/agrad/rev/matrix/mdivide_left_ldlt.hpp>
#include <stan/agrad/rev/matrix/mdivide_left_spd.hpp>
#include <stan/agrad/rev/matrix/mdivide_left_tri.hpp>
#include <stan/agrad/rev/matrix/multiply.hpp>
#include <stan/agrad/rev/matrix/multiply_lower_tri_self_transpose.hpp>
#include <stan/agrad/rev/matrix/quad_form.hpp>
#include <stan/agrad/rev/matrix/sd.hpp>
#include <stan/agrad/rev/matrix/softmax.hpp>
#include <stan/agrad/rev/matrix/sort.hpp>
#include <stan/agrad/rev/matrix/squared_distance.hpp>
#include <stan/agrad/rev/matrix/stan_print.hpp>
#include <stan/agrad/rev/matrix/stored_gradient_vari.hpp>
#include <stan/agrad/rev/matrix/sum.hpp>
#include <stan/agrad/rev/matrix/tcrossprod.hpp>
#include <stan/agrad/rev/matrix/to_var.hpp>
#include <stan/agrad/rev/matrix/trace_gen_inv_quad_form_ldlt.hpp>
#include <stan/agrad/rev/matrix/trace_gen_quad_form.hpp>
#include <stan/agrad/rev/matrix/trace_inv_quad_form_ldlt.hpp>
#include <stan/agrad/rev/matrix/trace_quad_form.hpp>
#include <stan/agrad/rev/matrix/typedefs.hpp>
#include <stan/agrad/rev/matrix/value_of.hpp>
#include <stan/agrad/rev/matrix/variance.hpp>

#endif
